@@ -34,6 +34,7 @@ from rest_framework.views import APIView
 
 from pulp_container.app import models, serializers
 from pulp_container.app.authorization import AuthorizationService
+from pulp_container.app.redirects import FileStorageRedirects, S3StorageRedirects
 from pulp_container.app.token_verification import TokenAuthentication, TokenPermission
 
 
@@ -107,9 +108,9 @@ class ManifestNotFound(NotFound):
         )
 
 
-class ManifestRenderer(BaseRenderer):
+class ContentRenderer(BaseRenderer):
     """
-    Rendered class for rendering Manifest responses.
+    Rendered class for rendering Manifest and Blob responses.
     """
 
     media_type = "*/*"
@@ -168,7 +169,7 @@ class ManifestResponse(Response):
             "Location": "/v2/{path}/manifests/{digest}".format(path=path, digest=manifest.digest),
             "Content-Length": size,
         }
-        super().__init__(headers=headers, status=status)
+        super().__init__(headers=headers, status=status, content_type=manifest.media_type)
 
 
 class BlobResponse(Response):
@@ -276,12 +277,12 @@ class ContainerRegistryApiMixin:
                 try:
                     with transaction.atomic():
                         repo_serializer = serializers.ContainerPushRepositorySerializer(
-                            data={"name": path}, context={"request": request},
+                            data={"name": path}, context={"request": request}
                         )
                         repo_serializer.is_valid(raise_exception=True)
                         repository = repo_serializer.create(repo_serializer.validated_data)
                         repo_href = serializers.ContainerPushRepositorySerializer(
-                            repository, context={"request": request},
+                            repository, context={"request": request}
                         ).data["pulp_href"]
 
                         dist_serializer = serializers.ContainerDistributionSerializer(
@@ -479,102 +480,87 @@ class BlobUploads(ContainerRegistryApiMixin, ViewSet):
             raise Exception("The digest did not match")
 
 
-class Blobs(ContainerRegistryApiMixin, ViewSet):
+class RedirectsMixin:
+    """
+    A mixin used for configuring how the redirects will work based on a storage type.
+    """
+
+    def __init__(self, *args, **kwargs):
+        """
+        Determine a storage type and initialize the redirect class according to that.
+        """
+        super().__init__(*args, **kwargs)
+
+        if settings.DEFAULT_FILE_STORAGE == "pulpcore.app.models.storage.FileSystem":
+            self.redirects_class = FileStorageRedirects
+        elif settings.DEFAULT_FILE_STORAGE == "storages.backends.s3boto3.S3Boto3Storage":
+            self.redirects_class = S3StorageRedirects
+        else:
+            raise NotImplementedError()
+
+
+class Blobs(RedirectsMixin, ContainerRegistryApiMixin, ViewSet):
     """
     ViewSet for interacting with Blobs
     """
 
+    renderer_classes = [ContentRenderer]
+
     def head(self, request, path, pk=None):
         """
         Responds to HEAD requests about blobs
-        :param request:
-        :param path:
-        :param digest:
-        :return:
         """
-        _, _, repository_version = self.get_drv_pull(path)
-        try:
-            blob = models.Blob.objects.get(digest=pk, pk__in=repository_version.content)
-        except models.Blob.DoesNotExist:
-            raise BlobNotFound(digest=pk)
-        return BlobResponse(blob, path, 200, request)
+        return self.get(request, path, pk=pk)
 
     def get(self, request, path, pk=None):
         """Handles GET requests for Blobs."""
         distribution, _, repository_version = self.get_drv_pull(path)
+        redirects = self.redirects_class(distribution, path, request)
+
         try:
             blob = models.Blob.objects.get(digest=pk, pk__in=repository_version.content)
         except models.Blob.DoesNotExist:
             raise BlobNotFound(digest=pk)
-        return distribution.redirect_to_content_app(
-            "{}/pulp/container/{}/blobs/{}".format(settings.CONTENT_ORIGIN, path, blob.digest),
-        )
+        return redirects.issue_blob_redirect(blob)
 
 
-class Manifests(ContainerRegistryApiMixin, ViewSet):
+class Manifests(RedirectsMixin, ContainerRegistryApiMixin, ViewSet):
     """
-    ViewSet for intereacting with Manifests
+    ViewSet for interacting with Manifests
     """
 
-    renderer_classes = [ManifestRenderer]
+    renderer_classes = [ContentRenderer]
     # The lookup regex does not allow /, ^, &, *, %, !, ~, @, #, +, =, ?
     lookup_value_regex = "[^/^&*%!~@#+=?]+"
 
     def head(self, request, path, pk=None):
         """
         Responds to HEAD requests about manifests by reference
-        :param request:
-        :param path:
-        :param digest:
-        :return:
         """
-        _, _, repository_version = self.get_drv_pull(path)
-        try:
-            if pk[:7] != "sha256:":
-                tag = models.Tag.objects.get(name=pk, pk__in=repository_version.content)
-                manifest = tag.tagged_manifest
-            else:
-                manifest = models.Manifest.objects.get(digest=pk, pk__in=repository_version.content)
-        except (models.Tag.DoesNotExist, models.Manifest.DoesNotExist):
-            raise ManifestNotFound(reference=pk)
 
-        return ManifestResponse(manifest, path, request)
+        return self.get(request, path, pk=pk)
 
     def get(self, request, path, pk=None):
         """
         Responds to GET requests about manifests by reference
-        :param request:
-        :param path:
-        :param digest:
-        :return:
         """
         distribution, _, repository_version = self.get_drv_pull(path)
+        redirects = self.redirects_class(distribution, path, request)
+
         try:
             if pk[:7] != "sha256:":
                 tag = models.Tag.objects.get(name=pk, pk__in=repository_version.content)
-                return distribution.redirect_to_content_app(
-                    "{}/pulp/container/{}/manifests/{}".format(
-                        settings.CONTENT_ORIGIN, path, tag.name,
-                    ),
-                )
+                return redirects.issue_tag_redirect(tag)
             else:
                 manifest = models.Manifest.objects.get(digest=pk, pk__in=repository_version.content)
         except (models.Tag.DoesNotExist, models.Manifest.DoesNotExist):
             raise ManifestNotFound(reference=pk)
 
-        return distribution.redirect_to_content_app(
-            "{}/pulp/container/{}/manifests/{}".format(
-                settings.CONTENT_ORIGIN, path, manifest.digest,
-            ),
-        )
+        return redirects.issue_manifest_redirect(manifest)
 
     def put(self, request, path, pk=None):
         """
         Responds with the actual manifest
-        :param request:
-        :param path:
-        :param pk:
-        :return:
         """
         _, repository = self.get_dr_push(request, path)
         # iterate over all the layers and create
