@@ -215,7 +215,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         tag = serializer.validated_data["tag"]
 
         result = enqueue_with_reservation(
-            tasks.untag_image, [repository], kwargs={"tag": tag, "repository_pk": repository.pk},
+            tasks.untag_image, [repository], kwargs={"tag": tag, "repository_pk": repository.pk}
         )
         return OperationPostponedResponse(result, request)
 
@@ -225,9 +225,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         responses={202: AsyncOperationResponseSerializer},
         request=serializers.RecursiveManageSerializer,
     )
-    @action(
-        detail=True, methods=["post"], serializer_class=serializers.RecursiveManageSerializer,
-    )
+    @action(detail=True, methods=["post"], serializer_class=serializers.RecursiveManageSerializer)
     def add(self, request, pk):
         """
         Queues a task that creates a new RepositoryVersion by adding content units.
@@ -255,9 +253,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         responses={202: AsyncOperationResponseSerializer},
         request=serializers.RecursiveManageSerializer,
     )
-    @action(
-        detail=True, methods=["post"], serializer_class=serializers.RecursiveManageSerializer,
-    )
+    @action(detail=True, methods=["post"], serializer_class=serializers.RecursiveManageSerializer)
     def remove(self, request, pk):
         """
         Queues a task that creates a new RepositoryVersion by removing content units.
@@ -300,7 +296,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         repository = self.get_object()
         source_latest = serializer.validated_data["source_repository_version"]
         content_tags_in_repo = source_latest.content.filter(pulp_type="container.tag")
-        tags_in_repo = models.Tag.objects.filter(pk__in=content_tags_in_repo,)
+        tags_in_repo = models.Tag.objects.filter(pk__in=content_tags_in_repo)
         if names is None:
             tags_to_add = tags_in_repo
         else:
@@ -322,9 +318,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         responses={202: AsyncOperationResponseSerializer},
         request=serializers.ManifestCopySerializer,
     )
-    @action(
-        detail=True, methods=["post"], serializer_class=serializers.ManifestCopySerializer,
-    )
+    @action(detail=True, methods=["post"], serializer_class=serializers.ManifestCopySerializer)
     def copy_manifests(self, request, pk):
         """
         Queues a task that creates a new RepositoryVersion by adding Manifests.
@@ -334,7 +328,7 @@ class ContainerRepositoryViewSet(RepositoryViewSet):
         repository = self.get_object()
         source_latest = serializer.validated_data["source_repository_version"]
         content_manifests_in_repo = source_latest.content.filter(pulp_type="container.manifest")
-        manifests_in_repo = models.Manifest.objects.filter(pk__in=content_manifests_in_repo,)
+        manifests_in_repo = models.Manifest.objects.filter(pk__in=content_manifests_in_repo)
         digests = request.data.get("digests")
         media_types = request.data.get("media_types")
         filters = {}
@@ -475,7 +469,7 @@ class ContainerDistributionViewSet(BaseDistributionViewSet):
             )
 
         async_result = enqueue_with_reservation(
-            tasks.general_multi_delete, reservations, args=(instance_ids,),
+            tasks.general_multi_delete, reservations, args=(instance_ids,)
         )
         return OperationPostponedResponse(async_result, request)
 
