@@ -1,6 +1,8 @@
 # coding=utf-8
 """Tests that verify that images served by Pulp can be pulled."""
 import contextlib
+import hashlib
+import json
 import requests
 import unittest
 from urllib.parse import urljoin
@@ -106,7 +108,7 @@ class PullContentTestCase(unittest.TestCase):
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo_version = cls.distributions_api.read(distribution.pulp_href)
             cls.teardown_cleanups.append(
-                (cls.distributions_api.delete, cls.distribution_with_repo_version.pulp_href,)
+                (cls.distributions_api.delete, cls.distribution_with_repo_version.pulp_href)
             )
 
             # remove callback if everything goes well
@@ -139,8 +141,7 @@ class PullContentTestCase(unittest.TestCase):
         )
 
     def test_api_performes_schema_conversion(self):
-        """Verify pull via token with accepted content type.
-        """
+        """Verify pull via token with accepted content type."""
         image_path = "/v2/{}/manifests/{}".format(self.distribution_with_repo.base_path, "latest")
         latest_image_url = urljoin(self.cfg.get_base_url(), image_path)
 
@@ -164,6 +165,17 @@ class PullContentTestCase(unittest.TestCase):
         base_content_type = content_response.headers["Content-Type"].split(";")[0]
         self.assertIn(base_content_type, {MEDIA_TYPE.MANIFEST_V1, MEDIA_TYPE.MANIFEST_V1_SIGNED})
 
+        header_digest = content_response.headers["Docker-Content-Digest"]
+        converted_manifest = json.loads(content_response.content)
+        converted_manifest.pop("signatures")
+        manifest_string = json.dumps(
+            converted_manifest, indent=3, sort_keys=True, separators=(",", ": ")
+        ).encode("utf-8")
+        # the header digest should be equal to the SHA256 hash computed from
+        # a manifest without signatures
+        computed_digest = hashlib.sha256(manifest_string).hexdigest()
+        self.assertEqual(computed_digest, header_digest, "The manifest digests are not equal")
+
     def test_pull_image_from_repository(self):
         """Verify that a client can pull the image from Pulp.
 
@@ -321,7 +333,7 @@ class PullOnDemandContentTestCase(unittest.TestCase):
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo_version = cls.distributions_api.read(distribution.pulp_href)
             cls.teardown_cleanups.append(
-                (cls.distributions_api.delete, cls.distribution_with_repo_version.pulp_href,)
+                (cls.distributions_api.delete, cls.distribution_with_repo_version.pulp_href)
             )
 
             # remove callback if everything goes well
