@@ -113,7 +113,7 @@ class TestManifestCopy(unittest.TestCase):
         """Passing only source version copies all manifests."""
         latest_from = self.repositories_api.read(self.from_repo.pulp_href)
         copy_response = self.repositories_api.copy_manifests(
-            self.to_repo.pulp_href, {"source_repository_version": latest_from.latest_version_href},
+            self.to_repo.pulp_href, {"source_repository_version": latest_from.latest_version_href}
         )
         monitor_task(copy_response.task)
 
@@ -151,8 +151,8 @@ class TestManifestCopy(unittest.TestCase):
         ).content_summary.present
         self.assertFalse("container.tag" in to_repo_content)
         self.assertEqual(to_repo_content["container.manifest"]["count"], 1)
-        # manifest_a has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 2)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        self.assertEqual(to_repo_content["container.blob"]["count"], 3)
 
     def test_copy_manifest_by_digest_and_media_type(self):
         """Specify a single manifest by digest to copy."""
@@ -178,8 +178,9 @@ class TestManifestCopy(unittest.TestCase):
         ).content_summary.present
         self.assertFalse("container.tag" in to_repo_content)
         self.assertEqual(to_repo_content["container.manifest"]["count"], 1)
-        # manifest_a has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 2)
+        # manifest_a has 3 blobs
+        # 3rd blob is the parent blob from apline repo
+        self.assertEqual(to_repo_content["container.blob"]["count"], 3)
 
     def test_copy_all_manifest_lists_by_media_type(self):
         """Specify the media_type, to copy all manifest lists."""
@@ -199,8 +200,9 @@ class TestManifestCopy(unittest.TestCase):
         self.assertFalse("container.tag" in to_repo_content)
         # Fixture has 4 manifest lists, which combined reference 5 manifests
         self.assertEqual(to_repo_content["container.manifest"]["count"], 9)
-        # each manifest (non-list) has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 10)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        # 11th blob is the parent blob from apline repo, which is shared by all other manifests
+        self.assertEqual(to_repo_content["container.blob"]["count"], 11)
 
     def test_copy_all_manifests_by_media_type(self):
         """Specify the media_type, to copy all manifest lists."""
@@ -220,8 +222,9 @@ class TestManifestCopy(unittest.TestCase):
         self.assertFalse("container.tag" in to_repo_content)
         # Fixture has 5 manifests that aren't manifest lists
         self.assertEqual(to_repo_content["container.manifest"]["count"], 5)
-        # each manifest (non-list) has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 10)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        # 11th blob is the parent blob from apline repo, which is shared by all other manifests
+        self.assertEqual(to_repo_content["container.blob"]["count"], 11)
 
     def test_fail_to_copy_invalid_manifest_media_type(self):
         """Specify the media_type, to copy all manifest lists."""
@@ -290,13 +293,14 @@ class TestManifestCopy(unittest.TestCase):
         self.assertFalse("container.tag" in to_repo_content)
         # each manifest list is a manifest and references 2 other manifests
         self.assertEqual(to_repo_content["container.manifest"]["count"], 6)
-        # each referenced manifest has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 8)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        # 9th blob is the parent blob from apline repo, which is shared by all other manifests
+        self.assertEqual(to_repo_content["container.blob"]["count"], 9)
 
     def test_copy_manifests_by_digest_empty_list(self):
         """Passing an empty list copies no manifests."""
         self.repositories_api.copy_manifests(
-            self.to_repo.pulp_href, {"source_repository": self.from_repo.pulp_href, "digests": []},
+            self.to_repo.pulp_href, {"source_repository": self.from_repo.pulp_href, "digests": []}
         )
         latest_to = self.repositories_api.read(self.to_repo.pulp_href)
         # Assert a new version was not created
@@ -386,7 +390,7 @@ class TestTagCopy(unittest.TestCase):
             self.from_repo.pulp_href
         ).latest_version_href
         copy_response = self.repositories_api.copy_tags(
-            self.to_repo.pulp_href, {"source_repository_version": latest_from_repo_href},
+            self.to_repo.pulp_href, {"source_repository_version": latest_from_repo_href}
         )
         monitor_task(copy_response.task)
 
@@ -417,13 +421,14 @@ class TestTagCopy(unittest.TestCase):
         self.assertEqual(to_repo_content["container.tag"]["count"], 2)
         # ml_i has 1 manifest list, 2 manifests, manifest_c has 1 manifest
         self.assertEqual(to_repo_content["container.manifest"]["count"], 4)
-        # each manifest (not manifest list) has 2 blobs
-        self.assertEqual(to_repo_content["container.blob"]["count"], 6)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        # 7th blob is the parent blob from apline repo, which is shared by all other manifests
+        self.assertEqual(to_repo_content["container.blob"]["count"], 7)
 
     def test_copy_tags_by_name_empty_list(self):
         """Passing an empty list of names copies nothing."""
         copy_response = self.repositories_api.copy_tags(
-            self.to_repo.pulp_href, {"source_repository": self.from_repo.pulp_href, "names": []},
+            self.to_repo.pulp_href, {"source_repository": self.from_repo.pulp_href, "names": []}
         )
         monitor_task(copy_response.task)
 
@@ -530,14 +535,14 @@ class TestRecursiveAdd(unittest.TestCase):
         # No tags added
         self.assertFalse("container.manifest-tag" in latest.content_summary.added)
 
-        # manifest a has 2 blobs
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
     def test_manifest_list_recursion(self):
         """Add a Manifest List, related manifests, and related blobs."""
         ml_i = (
-            self.tags_api.list(name="ml_i", repository_version=self.latest_from_version,)
+            self.tags_api.list(name="ml_i", repository_version=self.latest_from_version)
             .results[0]
             .tagged_manifest
         )
@@ -568,7 +573,9 @@ class TestRecursiveAdd(unittest.TestCase):
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 1)
         # 1 manifest list 2 manifests
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 3)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 4)
+        # each manifest (non-list) has 3 blobs, 1 blob is shared
+        # 5th blob is the parent blob from apline repo, which is shared by all other manifests
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 5)
 
     def test_tagged_manifest_recursion(self):
         """Add a tagged manifest and its related blobs."""
@@ -586,7 +593,7 @@ class TestRecursiveAdd(unittest.TestCase):
 
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
     def test_tag_replacement(self):
         """Add a tagged manifest to a repo with a tag of that name already in place."""
@@ -648,7 +655,7 @@ class TestRecursiveAdd(unittest.TestCase):
             .pulp_href
         )
         add_response = self.repositories_api.add(
-            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]},
+            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]}
         )
         monitor_task(add_response.task)
 
@@ -657,4 +664,4 @@ class TestRecursiveAdd(unittest.TestCase):
 
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 4)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 9)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 10)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 11)
