@@ -87,7 +87,7 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure test begins in the correct state
         self.assertFalse("container.tag" in latest.content_summary.added)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -97,7 +97,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest_version_href = self.repositories_api.read(self.to_repo.pulp_href).latest_version_href
         latest = self.versions_api.read(latest_version_href)
         self.assertEqual(latest.content_summary.present, {})
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 3)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 1)
 
     def test_remove_invalid_content_units(self):
@@ -125,7 +125,7 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure test begins in the correct state
         self.assertFalse("container.tag" in latest.content_summary.added)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -136,7 +136,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest = self.versions_api.read(latest_version_href)
         self.assertFalse("container.tag" in latest.content_summary.removed)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 3)
 
     def test_manifest_list_recursion(self):
         """Add a Manifest List, related manifests, and related blobs."""
@@ -153,7 +153,7 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure test begins in the correct state
         self.assertFalse("container.tag" in latest.content_summary.added)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 3)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 4)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 5)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -164,7 +164,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest = self.versions_api.read(latest_version_href)
         self.assertFalse("container.tag" in latest.content_summary.removed)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 3)
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 4)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 5)
 
     def test_tagged_manifest_list_recursion(self):
         """Add a tagged manifest list, and its related manifests and blobs."""
@@ -183,7 +183,7 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure test begins in the correct state
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 3)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 4)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 5)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -194,7 +194,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest = self.versions_api.read(latest_version_href)
         self.assertEqual(latest.content_summary.removed["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 3)
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 4)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 5)
 
     def test_tagged_manifest_recursion(self):
         """Add a tagged manifest and its related blobs."""
@@ -213,7 +213,7 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure valid starting state
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -225,7 +225,7 @@ class TestRecursiveRemove(unittest.TestCase):
 
         self.assertEqual(latest.content_summary.removed["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 3)
 
     def test_manifests_shared_blobs(self):
         """Starting with 2 manifests that share blobs, remove one of them."""
@@ -248,9 +248,9 @@ class TestRecursiveRemove(unittest.TestCase):
         # Ensure valid starting state
         self.assertFalse("container.tag" in latest.content_summary.added)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 2)
-        # manifest_a has 1 blob, 1 config blob, and manifest_e has 2 blob 1 config blob
-        # manifest_a blob is shared with manifest_e
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 4)
+        # manifest_a has 2 blobs, 1 config blob, and manifest_e has 3 blobs 1 config blob
+        # manifest_a blobs are shared with manifest_e
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 5)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -261,7 +261,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest = self.versions_api.read(latest_version_href)
         self.assertFalse("container.tag" in latest.content_summary.removed)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 1)
-        # Despite having 3 blobs, only 2 are removed, 1 is shared with manifest_a.
+        # Despite having 4 blobs, only 2 are removed, 2 is shared with manifest_a.
         self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 2)
 
     def test_manifest_lists_shared_manifests(self):
@@ -287,7 +287,7 @@ class TestRecursiveRemove(unittest.TestCase):
         self.assertFalse("container.tag" in latest.content_summary.added)
         # 2 manifest lists, each with 2 manifests, 1 manifest shared
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 5)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 6)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 7)
 
         # Actual test
         remove_response = self.repositories_api.remove(
@@ -324,7 +324,7 @@ class TestRecursiveRemove(unittest.TestCase):
             .pulp_href
         )
         add_response = self.repositories_api.add(
-            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]},
+            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]}
         )
         monitor_task(add_response.task)
         latest_version_href = self.repositories_api.read(self.to_repo.pulp_href).latest_version_href
@@ -332,10 +332,10 @@ class TestRecursiveRemove(unittest.TestCase):
 
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 4)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 9)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 10)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 11)
 
         remove_response = self.repositories_api.remove(
-            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]},
+            self.to_repo.pulp_href, {"content_units": [ml_i_tag, ml_ii_tag, ml_iii_tag, ml_iv_tag]}
         )
         monitor_task(remove_response.task)
         latest_version_href = self.repositories_api.read(self.to_repo.pulp_href).latest_version_href
@@ -343,7 +343,7 @@ class TestRecursiveRemove(unittest.TestCase):
 
         self.assertEqual(latest.content_summary.removed["container.tag"]["count"], 4)
         self.assertEqual(latest.content_summary.removed["container.manifest"]["count"], 9)
-        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 10)
+        self.assertEqual(latest.content_summary.removed["container.blob"]["count"], 11)
 
     def test_cannot_remove_tagged_manifest(self):
         """
@@ -360,7 +360,7 @@ class TestRecursiveRemove(unittest.TestCase):
         latest = self.versions_api.read(latest_version_href)
         self.assertEqual(latest.content_summary.added["container.tag"]["count"], 1)
         self.assertEqual(latest.content_summary.added["container.manifest"]["count"], 1)
-        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 2)
+        self.assertEqual(latest.content_summary.added["container.blob"]["count"], 3)
 
         remove_respone = self.repositories_api.remove(
             self.to_repo.pulp_href, {"content_units": [manifest_a_tag.tagged_manifest]}
